(define-module (kimapr packages misc)
  #:use-module (guix gexp)
  #:use-module (guix utils)
  #:use-module (guix download)
  #:use-module (guix packages)
  #:use-module (gnu packages lua)
  #:use-module (gnu packages video)
  #:use-module (gnu packages audio)
  #:use-module (gnu packages freedesktop)
  #:use-module (gnu packages gettext)
  #:use-module (gnu packages glib)
  #:use-module (gnu packages gnome)
  #:use-module (gnu packages gtk)
  #:use-module (gnu packages ninja)
  #:use-module (gnu packages pkg-config)
  #:use-module (gnu packages python)
  #:use-module (gnu packages python-xyz)
  #:use-module ((guix licenses)
                #:prefix license:)
  #:export (lua ffmpeg mpv accerciser))

(package
  (name "accerciser")
  (version "3.46.2")
  (source
   (origin
     (method url-fetch)
     (uri (string-append "mirror://gnome/sources/"
                         name
                         "/"
                         (version-major+minor version)
                         "/"
                         name
                         "-"
                         version
                         ".tar.xz"))
     (sha256
      (base32 "03kpjrs890wxmm1pffh3n9k3q1d5hrzplzsg7ilqgr943x2nkx5g"))))
  (build-system meson-build-system)
  (native-inputs (list gobject-introspection
                       yelp-tools
                       desktop-file-utils
                       `(,gtk+ "bin")
                       `(,glib "bin")
                       pkg-config
                       appstream))
  (arguments
   '(#:phases (modify-phases %standard-phases
                (add-after 'install 'wrap-orca
                  (lambda* (#:key outputs #:allow-other-keys)
                    (wrap-program (search-input-file outputs "bin/accerciser")
                      `("GI_TYPELIB_PATH" ":" prefix
                        (,(getenv "GI_TYPELIB_PATH")))
                      `("GUIX_PYTHONPATH" ":" prefix
                        (,(getenv "GUIX_PYTHONPATH")))
                      `("GSETTINGS_SCHEMA_DIR" =
                        (,(string-append (assoc-ref outputs "out")
                                         "/share/glib-2.0/schemas")))))))))
  (inputs (list gtk+
                glib
                gnu-gettext
                python-3.10
                python-pygobject
                python-dbus
                python-pyatspi
                python-pyxdg
                python-pycairo
                python-ipython))
  (synopsis "Interactive accessibility explorer")
  (home-page "https://gitlab.gnome.org/GNOME/accerciser")
  (description
   "Accerciser is an interactive Python accessibility explorer for the GNOME
desktop. It uses AT-SPI2 to inspect and control widgets, allowing you to check
if an application is providing correct information to assistive technologies
and automated test frameworks. Accerciser has a simple plugin framework which
you can use to create custom views of accessibility information.

In essence, Accerciser is a next generation at-poke tool.")
  (license license:bsd-3))

(define-public lua
  (package
    (inherit lua-5.4)
    (arguments
     (substitute-keyword-arguments (package-arguments lua-5.4)
       ((#:make-flags flags)
        (append (list-head flags
                           (- (length flags) 1))
                '("linux-readline")))))))

(define-public ffmpeg
  (package
    (inherit ffmpeg)
    (arguments
     (substitute-keyword-arguments (package-arguments ffmpeg)
       ((#:configure-flags flags)
        #~(cons* "--enable-libopenmpt"
                 #$flags))))
    (inputs (modify-inputs (package-inputs ffmpeg)
              (prepend libopenmpt)))))

(define-public mpv
  ((package-input-rewriting `((,ffmpeg unquote ffmpeg-mod)))
   mpv))
